document.addEventListener('DOMContentLoaded', () => {
  // Initialize demo database
  let demoDb = [];
  
  const demoInput = document.getElementById('demoInput');
  const demoButton = document.getElementById('demoButton');
  const demoList = document.getElementById('demoList');
  
  function addDocument(text) {
    const doc = {
      _id: Date.now().toString(),
      text: text,
      createdAt: new Date().toISOString()
    };
    demoDb.unshift(doc);
    updateDemoList();
  }
  
  function updateDemoList() {
    demoList.innerHTML = '';
    demoDb.slice(0, 5).forEach(doc => {
      const li = document.createElement('li');
      li.textContent = doc.text;
      demoList.appendChild(li);
    });
  }
  
  demoButton.addEventListener('click', () => {
    const text = demoInput.value.trim();
    if (text) {
      addDocument(text);
      demoInput.value = '';
    }
  });
  
  demoInput.addEventListener('keypress', (e) => {
    if (e.key === 'Enter') {
      const text = demoInput.value.trim();
      if (text) {
        addDocument(text);
        demoInput.value = '';
      }
    }
  });
  
  // Add some initial demo data
  addDocument('Example document 1');
  addDocument('Example document 2');
});

// Add smooth scrolling for anchor links
document.querySelectorAll('a[href^="#"]').forEach(anchor => {
  anchor.addEventListener('click', function (e) {
    e.preventDefault();
    document.querySelector(this.getAttribute('href')).scrollIntoView({
      behavior: 'smooth'
    });
  });
});

// Add intersection observer for fade-in animations
const observer = new IntersectionObserver((entries) => {
  entries.forEach(entry => {
    if (entry.isIntersecting) {
      entry.target.classList.add('visible');
    }
  });
}, {
  threshold: 0.1
});

document.querySelectorAll('.feature-card, .code-container, .demo-container').forEach((el) => {
  observer.observe(el);
});